ArgumentDeclaration.parse constructor
Parses an argument declaration from contents, which should be of the
form @rule name(args) {.
If passed, url is the name of the file from which contents comes.
Throws a SassFormatException if parsing fails.
Implementation
factory ArgumentDeclaration.parse(String contents,
{Object? url, Logger? logger}) =>
ScssParser(contents, url: url, logger: logger).parseArgumentDeclaration();