ForwardRule class final
A @forward rule.
- Inheritance
- Implemented types
Constructors
-
ForwardRule(Uri url, FileSpan span, {String? prefix, Iterable<
ConfiguredVariable> ? configuration}) -
Creates a
@forwardrule that allows all members to be accessed. -
ForwardRule.hide(Uri url, FileSpan span, {String? prefix, Iterable<
ConfiguredVariable> ? configuration}) -
Creates a
@forwardrule that allows only members not included inhiddenMixinsAndFunctionsandhiddenVariablesto be accessed. -
ForwardRule.show(Uri url, Iterable<
String> shownMixinsAndFunctions, Iterable<String> shownVariables, FileSpan span, {String? prefix, Iterable<ConfiguredVariable> ? configuration}) -
Creates a
@forwardrule that allows only members included inshownMixinsAndFunctionsandshownVariablesto be accessed.
Properties
-
configuration
→ List<
ConfiguredVariable> -
A list of variable assignments used to configure the loaded modules.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
The set of mixin and function names that may not be accessed from the
forwarded module.
final
-
The set of variable names (without
$) that may be accessed from the forwarded module.final - prefix → String?
-
The prefix to add to the beginning of the names of members of the used
module, or
nullif member names are used as-is.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shownMixinsAndFunctions
→ Set<
String> ? -
The set of mixin and function names that may be accessed from the
forwarded module.
final
-
shownVariables
→ Set<
String> ? -
The set of variable names (without
$) that may be accessed from the forwarded module.final - span → FileSpan
-
The source span associated with the node.
final
- url → Uri
-
The URI of the module to forward.
final
- urlSpan → FileSpan
-
The span of the URL for this dependency, including the quotes.
no setteroverride
Methods
-
accept<
T> (StatementVisitor< T> visitor) → T -
Calls the appropriate visit method on
visitor.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited