hiddenVariables property
The set of variable names (without $) that may be accessed from the
forwarded module.
If this is empty, any variables may be accessed. If it's null, it
imposes no restrictions on which variables may be accessed.
If this is non-null, shownMixinsAndFunctions and shownVariables are
guaranteed to both be null and hiddenMixinsAndFunctions is guaranteed
to be non-null.
Implementation
final Set<String>? hiddenVariables;