convertToMatch method
Returns a copy of this number, converted to the same units as other.
Note that convertValueToMatch is generally more efficient if the value is going to be accessed directly.
Throws a SassScriptException if this number's units aren't compatible
with other's units, or if either number is unitless but the other is
not.
If this came from a function argument, name is the argument name
(without the $) and otherName is the argument name for other. These
are used for error reporting.
Implementation
SassNumber convertToMatch(SassNumber other,
[String? name, String? otherName]) =>
SassNumber.withUnits(convertValueToMatch(other, name, otherName),
numeratorUnits: other.numeratorUnits,
denominatorUnits: other.denominatorUnits);