namespace property
The selector namespace.
If this is null, this matches all elements in the default namespace. If
it's the empty string, this matches all elements that aren't in any
namespace. If it's *, this matches all elements in any namespace.
Otherwise, it matches all elements in the given namespace.
Implementation
final String? namespace;