AstSearchVisitor<T> mixin
A visitor that recursively traverses each statement and expression in a Sass
AST whose visit* methods default to returning null, but which returns
the first non-null value returned by any method.
This extends StatementSearchVisitor to traverse each expression in
addition to each statement, as well as each selector for ASTs where
parseSelectors: true was passed to Stylesheet.parse. It supports the
same additional methods as RecursiveAstVisitor.
- Superclass constraints
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitArgumentList(
ArgumentList invocation) → T? -
Visits each expression in an
invocation. -
visitAtRootRule(
AtRootRule node) → T? -
override
-
visitAtRule(
AtRule node) → T? -
override
-
visitAttributeSelector(
InterpolatedAttributeSelector node) → T? -
visitBinaryOperationExpression(
BinaryOperationExpression node) → T? -
override
-
visitBooleanExpression(
BooleanExpression node) → T? -
override
-
visitCallableDeclaration(
CallableDeclaration node) → T? -
Visits each of
node's expressions and children.override -
visitChildren(
List< Statement> children) → T? -
Visits each child in
children.inherited -
visitClassSelector(
InterpolatedClassSelector node) → T? -
visitColorExpression(
ColorExpression node) → T? -
override
-
visitComplexSelector(
InterpolatedComplexSelector node) → T? -
visitCompoundSelector(
InterpolatedCompoundSelector compound) → T? -
inherited
-
visitContentBlock(
ContentBlock node) → T? -
inherited
-
visitContentRule(
ContentRule node) → T? -
override
-
visitDebugRule(
DebugRule node) → T? -
override
-
visitDeclaration(
Declaration node) → T? -
override
-
visitEachRule(
EachRule node) → T? -
override
-
visitErrorRule(
ErrorRule node) → T? -
override
-
visitExpression(
Expression expression) → T? -
visitExtendRule(
ExtendRule node) → T? -
override
-
visitForRule(
ForRule node) → T? -
override
-
visitForwardRule(
ForwardRule node) → T? -
override
-
visitFunctionExpression(
FunctionExpression node) → T? -
override
-
visitFunctionRule(
FunctionRule node) → T? -
inherited
-
visitIDSelector(
InterpolatedIDSelector node) → T? -
visitIfConditionFunction(
IfConditionFunction node) → T? -
visitIfConditionNegation(
IfConditionNegation node) → T? -
visitIfConditionOperation(
IfConditionOperation node) → T? -
visitIfConditionParenthesized(
IfConditionParenthesized node) → T? -
visitIfConditionRaw(
IfConditionRaw node) → T? -
visitIfConditionSass(
IfConditionSass node) → T? -
visitIfExpression(
IfExpression node) → T? -
override
-
visitIfRule(
IfRule node) → T? -
override
-
visitImportRule(
ImportRule node) → T? -
override
-
visitIncludeRule(
IncludeRule node) → T? -
override
-
visitInterpolatedFunctionExpression(
InterpolatedFunctionExpression node) → T? -
override
-
visitInterpolation(
Interpolation interpolation) → T? -
Visits each expression in an
interpolation. -
visitLegacyIfExpression(
LegacyIfExpression node) → T? -
override
-
visitListExpression(
ListExpression node) → T? -
override
-
visitLoudComment(
LoudComment node) → T? -
override
-
visitMapExpression(
MapExpression node) → T? -
override
-
visitMediaRule(
MediaRule node) → T? -
override
-
visitMixinRule(
MixinRule node) → T? -
inherited
-
visitNullExpression(
NullExpression node) → T? -
override
-
visitNumberExpression(
NumberExpression node) → T? -
override
-
visitParenthesizedExpression(
ParenthesizedExpression node) → T? -
override
-
visitParentSelector(
InterpolatedParentSelector node) → T? -
visitPlaceholderSelector(
InterpolatedPlaceholderSelector node) → T? -
visitPseudoSelector(
InterpolatedPseudoSelector node) → T? -
visitQualifiedName(
InterpolatedQualifiedName node) → T? -
Visits each expression in
node. -
visitReturnRule(
ReturnRule node) → T? -
override
-
visitSelectorExpression(
SelectorExpression node) → T? -
override
-
visitSelectorList(
InterpolatedSelectorList node) → T? -
visitSilentComment(
SilentComment node) → T? -
inherited
-
visitStringExpression(
StringExpression node) → T? -
override
-
visitStyleRule(
StyleRule node) → T? -
override
-
visitStylesheet(
Stylesheet node) → T? -
inherited
-
visitSupportsCondition(
SupportsCondition condition) → T? -
Visits each expression in
condition. -
visitSupportsExpression(
SupportsExpression node) → T? -
override
-
visitSupportsRule(
SupportsRule node) → T? -
override
-
visitTypeSelector(
InterpolatedTypeSelector node) → T? -
visitUnaryOperationExpression(
UnaryOperationExpression node) → T? -
override
-
visitUniversalSelector(
InterpolatedUniversalSelector universal) → T? -
inherited
-
visitUniverssalSelector(
InterpolatedUniversalSelector node) → T? -
visitUseRule(
UseRule node) → T? -
override
-
visitValueExpression(
ValueExpression node) → T? -
override
-
visitVariableDeclaration(
VariableDeclaration node) → T? -
override
-
visitVariableExpression(
VariableExpression node) → T? -
override
-
visitWarnRule(
WarnRule node) → T? -
override
-
visitWhileRule(
WhileRule node) → T? -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited