IfConditionNegation class final
A negated condition.
- Inheritance
-
- Object
- IfConditionExpression
- IfConditionNegation
Constructors
- IfConditionNegation(IfConditionExpression expression, FileSpan span)
Properties
- expression → IfConditionExpression
-
The expression negated by this.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → FileSpan
-
The source span associated with the node.
final
Methods
-
accept<
T> (IfConditionExpressionVisitor< T> visitor) → T -
Calls the appropriate visit method on
visitor.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited