InterpolatedComplexSelector class final

A complex selector before interoplation is resolved.

Unlike ComplexSelector, this is parsed during the initial stylesheet parse when parseSelectors: true is passed to Stylesheet.parse.

Inheritance

Constructors

InterpolatedComplexSelector(Iterable<InterpolatedComplexSelectorComponent> components, FileSpan span, {CssValue<Combinator>? leadingCombinator})

Properties

components List<InterpolatedComplexSelectorComponent>
The components of this selector.
final
hashCode int
The hash code for this object.
no setterinherited
leadingCombinator → CssValue<Combinator>?
This selector's leading combinator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The source span associated with the node.
final

Methods

accept<T>(InterpolatedSelectorVisitor<T> visitor) → T
Calls the appropriate visit method on visitor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited