InterpolatedComplexSelectorComponent class final

A component of a InterpolatedComplexSelector.

Unlike ComplexSelectorComponent, this is parsed during the initial stylesheet parse when parseSelectors: true is passed to Stylesheet.parse.

Implemented types

Constructors

InterpolatedComplexSelectorComponent(InterpolatedCompoundSelector selector, FileSpan span, {CssValue<Combinator>? combinator})

Properties

combinator → CssValue<Combinator>?
This selector's combinator.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selector InterpolatedCompoundSelector
This component's compound selector.
final
span → FileSpan
The source span associated with the node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited