InterpolatedParentSelector class final

A parent selector.

Unlike ParentSelector, this is parsed during the initial stylesheet parse when parseSelectors: true is passed to Stylesheet.parse.

Inheritance

Constructors

InterpolatedParentSelector(FileSpan span, {Interpolation? suffix})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The source span associated with the node.
final
suffix Interpolation?
The suffix that will be added to the parent selector after it's been resolved.
final

Methods

accept<T>(InterpolatedSelectorVisitor<T> visitor) → T
Calls the appropriate visit method on visitor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited