InterpolatedTypeSelector class final

An type selector.

Unlike TypeSelector, this is parsed during the initial stylesheet parse when parseSelectors: true is passed to Stylesheet.parse.

Inheritance

Constructors

InterpolatedTypeSelector(InterpolatedQualifiedName name)
Creates a type selector that matches any element with a property of the given name.

Properties

hashCode int
The hash code for this object.
no setterinherited
name InterpolatedQualifiedName
The element name being selected for.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The source span associated with the node.
no setteroverride

Methods

accept<T>(InterpolatedSelectorVisitor<T> visitor) → T
Calls the appropriate visit method on visitor.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited