RecursiveAstVisitor mixin

A visitor that recursively traverses each statement and expression in a Sass AST.

This extends RecursiveStatementVisitor to traverse each expression in addition to each statement. It adds even more protected methods:

Superclass constraints
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visitArgumentList(ArgumentList invocation) → void
Visits each expression in an invocation.
visitAtRootRule(AtRootRule node) → void
override
visitAtRule(AtRule node) → void
override
visitAttributeSelector(InterpolatedAttributeSelector node) → void
visitBinaryOperationExpression(BinaryOperationExpression node) → void
override
visitBooleanExpression(BooleanExpression node) → void
override
visitCallableDeclaration(CallableDeclaration node) → void
Visits each of node's children.
override
visitChildren(List<Statement> children) → void
Visits each child in children.
inherited
visitClassSelector(InterpolatedClassSelector node) → void
visitColorExpression(ColorExpression node) → void
override
visitComplexSelector(InterpolatedComplexSelector node) → void
visitCompoundSelector(InterpolatedCompoundSelector node) → void
visitContentBlock(ContentBlock node) → void
inherited
visitContentRule(ContentRule node) → void
override
visitDebugRule(DebugRule node) → void
override
visitDeclaration(Declaration node) → void
override
visitEachRule(EachRule node) → void
override
visitErrorRule(ErrorRule node) → void
override
visitExpression(Expression expression) → void
visitExtendRule(ExtendRule node) → void
override
visitForRule(ForRule node) → void
override
visitForwardRule(ForwardRule node) → void
override
visitFunctionExpression(FunctionExpression node) → void
override
visitFunctionRule(FunctionRule node) → void
inherited
visitIDSelector(InterpolatedIDSelector node) → void
visitIfConditionFunction(IfConditionFunction node) → void
visitIfConditionNegation(IfConditionNegation node) → void
visitIfConditionOperation(IfConditionOperation node) → void
visitIfConditionParenthesized(IfConditionParenthesized node) → void
visitIfConditionRaw(IfConditionRaw node) → void
visitIfConditionSass(IfConditionSass node) → void
visitIfExpression(IfExpression node) → void
override
visitIfRule(IfRule node) → void
override
visitImportRule(ImportRule node) → void
override
visitIncludeRule(IncludeRule node) → void
override
visitInterpolatedFunctionExpression(InterpolatedFunctionExpression node) → void
override
visitInterpolation(Interpolation interpolation) → void
Visits each expression in an interpolation.
visitLegacyIfExpression(LegacyIfExpression node) → void
override
visitListExpression(ListExpression node) → void
override
visitLoudComment(LoudComment node) → void
override
visitMapExpression(MapExpression node) → void
override
visitMediaRule(MediaRule node) → void
override
visitMixinRule(MixinRule node) → void
inherited
visitNullExpression(NullExpression node) → void
override
visitNumberExpression(NumberExpression node) → void
override
visitParenthesizedExpression(ParenthesizedExpression node) → void
override
visitParentSelector(InterpolatedParentSelector node) → void
visitPlaceholderSelector(InterpolatedPlaceholderSelector node) → void
visitPseudoSelector(InterpolatedPseudoSelector node) → void
visitQualifiedName(InterpolatedQualifiedName node) → void
Visits each interpolatoin in node.
visitReturnRule(ReturnRule node) → void
override
visitSelectorExpression(SelectorExpression node) → void
override
visitSelectorList(InterpolatedSelectorList node) → void
visitSilentComment(SilentComment node) → void
inherited
visitStringExpression(StringExpression node) → void
override
visitStyleRule(StyleRule node) → void
override
visitStylesheet(Stylesheet node) → void
inherited
visitSupportsCondition(SupportsCondition condition) → void
Visits each expression in condition.
visitSupportsExpression(SupportsExpression node) → void
override
visitSupportsRule(SupportsRule node) → void
override
visitTypeSelector(InterpolatedTypeSelector node) → void
visitUnaryOperationExpression(UnaryOperationExpression node) → void
override
visitUniversalSelector(InterpolatedUniversalSelector node) → void
visitUseRule(UseRule node) → void
override
visitValueExpression(ValueExpression node) → void
override
visitVariableDeclaration(VariableDeclaration node) → void
override
visitVariableExpression(VariableExpression node) → void
override
visitWarnRule(WarnRule node) → void
override
visitWhileRule(WhileRule node) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited