span property
The source span associated with the node.
This indicates where in the source Sass or SCSS stylesheet the node was defined.
The source span associated with the node.
This indicates where in the source Sass or SCSS stylesheet the node was defined.