SupportsDeclaration class final

A condition that selects for browsers where a given declaration is supported.

Implemented types

Constructors

SupportsDeclaration(Expression name, Expression value, FileSpan span)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → Expression
The name of the declaration being tested.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The source span associated with the node.
final
value → Expression
The value of the declaration being tested.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited