span property
The source span associated with the node.
This indicates where in the source Sass or SCSS stylesheet the node was defined.
Implementation
@override
final FileSpan span;
The source span associated with the node.
This indicates where in the source Sass or SCSS stylesheet the node was defined.
@override
final FileSpan span;