SupportsOperation class final

An operation defining the relationship between two conditions.

Implemented types

Constructors

SupportsOperation(SupportsCondition left, SupportsCondition right, BooleanOperator operator, FileSpan span)

Properties

hashCode → int
The hash code for this object.
no setterinherited
left → SupportsCondition
The left-hand operand.
final
operator → BooleanOperator
The operator.
final
The right-hand operand.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → FileSpan
The source span associated with the node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited