IfConditionRaw class final
A chunk of raw text, possibly with interpolations.
This is used to represent explicit interpolation, as well as whole expressions where arbitrary substitutions are used in place of operators.
- Inheritance
-
- Object
- IfConditionExpression
- IfConditionRaw
Constructors
- IfConditionRaw(Interpolation text)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → FileSpan
-
The source span associated with the node.
no setteroverride
- text → Interpolation
-
The text that encompasses this condition.
final
Methods
-
accept<
T> (IfConditionExpressionVisitor< T> visitor) → T -
Calls the appropriate visit method on
visitor.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited