ParameterList class final
An parameter declaration, as for a function or mixin definition.
- Implemented types
Constructors
-
ParameterList(Iterable<
Parameter> parameters, FileSpan span, {String? restParameter}) - ParameterList.empty(FileSpan span)
- Creates a declaration that declares no parameters.
- ParameterList.parse(String contents, {Object? url})
-
Parses an parameter declaration from
contents, which should be of the form@rule name(args) {.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Returns whether this declaration takes no parameters.
no setter
-
parameters
→ List<
Parameter> -
The parameters that are taken.
final
- restParameter → String?
-
The name of the rest parameter (as in
$args...), ornullif none was declared.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → FileSpan
-
The source span associated with the node.
final
- spanWithName → FileSpan
-
Returns span expanded to include an identifier immediately before the
declaration, if possible.
no setter
Methods
-
matches(
int positional, Set< String> names) → bool -
Returns whether
positionalandnamesare valid for this parameter declaration. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
verify(
int positional, Set< String> names) → void -
Throws a
SassScriptExceptionifpositionalandnamesaren't valid for this parameter declaration.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited